@@ -5,13 +5,13 @@ use locale;
 use Log::ger;
 use Moo;
 extends 'Org::Element';
-with 'Org::Element::Role';
-with 'Org::Element::BlockRole';
+with 'Org::ElementRole';
+with 'Org::ElementRole::Block';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-03-27'; # DATE
+our $DATE = '2022-06-23'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.557'; # VERSION
+our $VERSION = '0.558'; # VERSION
 
 has _dummy => (is => 'rw'); # workaround Moo bug
 
@@ -125,7 +125,7 @@ Org::Element::Table - Represent Org table
 
 =head1 VERSION
 
-This document describes version 0.557 of Org::Element::Table (from Perl distribution Org-Parser), released on 2022-03-27.
+This document describes version 0.558 of Org::Element::Table (from Perl distribution Org-Parser), released on 2022-06-23.
 
 =head1 DESCRIPTION
 
