@@ -4,13 +4,13 @@ use 5.010;
 use locale;
 use Moo;
 extends 'Org::Element';
-with 'Org::Element::Role';
-with 'Org::Element::InlineRole';
+with 'Org::ElementRole';
+with 'Org::ElementRole::Inline';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-03-27'; # DATE
+our $DATE = '2022-06-23'; # DATE
 our $DIST = 'Org-Parser'; # DIST
-our $VERSION = '0.557'; # VERSION
+our $VERSION = '0.558'; # VERSION
 
 has target => (is => 'rw');
 
@@ -39,7 +39,7 @@ Org::Element::Target - Represent Org target
 
 =head1 VERSION
 
-This document describes version 0.557 of Org::Element::Target (from Perl distribution Org-Parser), released on 2022-03-27.
+This document describes version 0.558 of Org::Element::Target (from Perl distribution Org-Parser), released on 2022-06-23.
 
 =head1 DESCRIPTION
 
@@ -57,7 +57,7 @@ From L<Org::Element>.
 
 =head2 as_text => str
 
-From L<Org::Element::InlineRole>.
+From L<Org::ElementRole::Inline>.
 
 =head1 HOMEPAGE
 
